@@ -38,6 +38,25 @@ class GreengrassCoreIPCClientV2:
             executor = concurrent.futures.ThreadPoolExecutor()
         self.executor = executor
 
+    def close(self, *, executor_wait=True) -> concurrent.futures.Future:
+        """
+        Close the underlying connection and shutdown the event executor (if any)
+
+        Args:
+            executor_wait: If true (default), then this method will block until the executor finishes running
+                all tasks and shuts down.
+
+        Returns:
+            The future which will complete
+            when the shutdown process is done. The future will have an
+            exception if shutdown was caused by an error, or a result
+            of None if the shutdown was clean and user-initiated.
+        """
+        fut = self.client.close()
+        if self.executor is not None:
+            self.executor.shutdown(wait=executor_wait)
+        return fut
+
     def __combine_futures(self, future1: concurrent.futures.Future,
                           future2: concurrent.futures.Future) -> concurrent.futures.Future:
         def callback(*args, **kwargs):
